@@ -10,6 +10,7 @@ class SignatureAuthentication(authentication.BaseAuthentication):
     SIGNATURE_HEADERS_RE = re.compile('headers="([\(\)\sa-z0-9-]+?)"')
 
     API_KEY_HEADER = 'X-Api-Key'
+    ALGORITHM = 'hmac-sha256'
 
     def get_signature_from_signature_string(self, signature):
         """Return the signature from the signature header or None."""
@@ -65,7 +66,7 @@ class SignatureAuthentication(authentication.BaseAuthentication):
         # Sign string and compare.
         signer = HeaderSigner(
             key_id=user_api_key, secret=user_secret,
-            headers=signature_headers, algorithm='hmac-sha256')
+            headers=signature_headers, algorithm=self.ALGORITHM)
         signed = signer.sign(unsigned, method=request.method, path=path)
         return signed['authorization']
 
